pub enum MetricFamilyType {
Counter,
Gauge,
String,
}Expand description
An enum representing various metric family types
Variants
Counter
A counter metric family type which is a monotonically increasing value
Gauge
A gauge metric family type which is a value that can go up and down
String
A string metric family type