pub struct ListOutput {
pub name: String,
pub value: Value,
pub object: Option<String>,
pub fields: Option<HashMap<String, Value>>,
}Expand description
Output parameters for the List method.
Fields
name: Stringvalue: Valueobject: Option<String>fields: Option<HashMap<String, Value>>Implementations
Sourceimpl ListOutput
impl ListOutput
Sourcepub fn name_suffix(&self) -> &str
pub fn name_suffix(&self) -> &str
Returns the name of the metric
Sourcepub fn object_name(&self) -> String
pub fn object_name(&self) -> String
Returns the object name or empty string if not present
Sourcepub fn value_as_string(&self) -> &str
pub fn value_as_string(&self) -> &str
Returns the string value. Caller must validate value is a string first.
Sourcepub fn value_as_int(&self) -> i64
pub fn value_as_int(&self) -> i64
Returns the int value. Caller must validate value is an integer first.
Sourcepub fn value_as_bool(&self) -> bool
pub fn value_as_bool(&self) -> bool
Returns the bool value. Caller must validate value is a bool first.
Sourcepub fn get_field_as_str(&self, field_name: &str) -> Option<&str>
pub fn get_field_as_str(&self, field_name: &str) -> Option<&str>
Extract a string field value from the fields map by field name